@@ -21,9 +21,11 @@ def make_workspace(name):
         content = f.read()
     with open(os.path.join(project, 'config', 'configuration.ini'), "w", encoding='utf-8') as f:
         content = content % (os.path.join(os.getcwd(), name),
+                             os.path.join(os.getcwd(), name, "data"),
                              os.path.join(os.getcwd(), name, "data"),
                              os.path.join(os.getcwd(), name, "result"),
-                             os.path.join(os.getcwd(), name, "log"))
+                             os.path.join(os.getcwd(), name, "log"),
+                             os.path.join(os.getcwd(), name, "result"))
         f.write(content)
 
 def main():
